@@ -57,21 +57,19 @@
 #include <KStandardGameAction>
 #include <KStandardAction>
 
-#include <KAction>
+#include <QAction>
 #include <KActionCollection>
 #include <KConfigDialog>
-#include <KDebug>
-#include <KFileDialog>
-#include <KGlobal>
-#include <KIcon>
-#include <KLocale>
+#include <QDebug>
+#include <QFileDialog>
+#include <QIcon>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KRandom>
 #include <KRecentFilesAction>
-#include <KStandardDirs>
-#include <KStatusBar>
-#include <KMenuBar>
-#include <KTemporaryFile>
+#include <QStatusBar>
+#include <QMenuBar>
+#include <QTemporaryFile>
 #include <KToggleAction>
 #include <KToolInvocation>
 #include <KXMLGUIFactory>
@@ -81,13 +79,16 @@
 #include <QtCore/QPointer>
 #include <QtCore/QTimer>
 #include <QtCore/QXmlStreamReader>
-#include <QtGui/QDesktopWidget>
-#include <QtGui/QKeySequence>
+#include <QDesktopWidget>
+#include <QKeySequence>
+#include <KHelpClient>
+#include <QStandardPaths>
+#include <KSharedConfig>
 
 
 namespace
 {
-    const KUrl dialogUrl( "kfiledialog:///kpat" );
+    const QUrl dialogUrl( "kfiledialog:///kpat" );
     const QString saveFileMimeType( "application/vnd.kde.kpatience.savedgame" );
     const QString legacySaveFileMimeType( "application/vnd.kde.kpatience.savedstate" );
 }
@@ -134,9 +135,9 @@ MainWindow::MainWindow()
 
 MainWindow::~MainWindow()
 {
-    m_recentFilesAction->saveEntries(KGlobal::config()->group( QString() ));
+    m_recentFilesAction->saveEntries(KSharedConfig::openConfig()->group( QString() ));
 
-    Settings::self()->writeConfig();
+    Settings::self()->save();
 
     delete m_dealer;
     delete m_view;
@@ -146,25 +147,25 @@ MainWindow::~MainWindow()
 
 void MainWindow::setupActions()
 {
-    KAction *a;
+    QAction *a;
 
     // Game Menu
     a = actionCollection()->addAction( QLatin1String( "new_game" ));
     a->setText(i18nc("Start a new game of a different type","New &Game..."));
-    a->setIcon( KIcon( QLatin1String( "document-new" )) );
-    a->setShortcuts( KShortcut( Qt::ControlModifier | Qt::ShiftModifier | Qt::Key_N ) );
-    connect( a, SIGNAL(triggered(bool)), SLOT(slotShowGameSelectionScreen()) );
+    a->setIcon( QIcon::fromTheme( QLatin1String( "document-new" )) );
+    actionCollection()->setDefaultShortcut(a, Qt::CTRL + Qt::SHIFT + Qt::Key_N);
+    connect(a, &QAction::triggered, this, &MainWindow::slotShowGameSelectionScreen);
 
     a = actionCollection()->addAction( QLatin1String( "new_deal" ));
     a->setText(i18nc("Start a new game of without changing the game type", "New &Deal"));
-    a->setIcon( KIcon( QLatin1String( "document-new" )) );
-    a->setShortcuts( KShortcut( Qt::ControlModifier | Qt::Key_N ) );
-    connect( a, SIGNAL(triggered(bool)), SLOT(newGame()) );
+    a->setIcon( QIcon::fromTheme( QLatin1String( "document-new" )) );
+    actionCollection()->setDefaultShortcut(a, Qt::CTRL + Qt::Key_N);
+    connect(a, &QAction::triggered, this, &MainWindow::newGame);
 
     a = actionCollection()->addAction( QLatin1String( "new_numbered_deal" ));
     a->setText(i18nc("Start a game by giving its particular number", "New &Numbered Deal..."));
-    a->setShortcut( KShortcut( Qt::ControlModifier | Qt::Key_D ) );
-    connect( a, SIGNAL(triggered(bool)), SLOT(newNumberedDeal()) );
+    actionCollection()->setDefaultShortcut(a, Qt::CTRL + Qt::Key_D);
+    connect(a, &QAction::triggered, this, &MainWindow::newNumberedDeal);
 
     a = KStandardGameAction::restart(this, SLOT(restart()), actionCollection());
     a->setText(i18nc("Replay the current deal from the start", "Restart Deal"));
@@ -174,31 +175,31 @@ void MainWindow::setupActions()
     // the toolbar if they wish.
     a = actionCollection()->addAction( QLatin1String( "next_deal" ));
     a->setText(i18nc("Start the game with the number one greater than the current one", "Next Deal"));
-    a->setIcon( KIcon( QLatin1String( "go-next" )) );
-    a->setShortcut( KShortcut( Qt::ControlModifier | Qt::Key_Plus ) );
-    connect( a, SIGNAL(triggered(bool)), this, SLOT(nextDeal()) );
+    a->setIcon( QIcon::fromTheme( QLatin1String( "go-next" )) );
+    actionCollection()->setDefaultShortcut(a, Qt::CTRL + Qt::Key_Plus);
+    connect(a, &QAction::triggered, this, &MainWindow::nextDeal);
 
     // Note that this action is not shown in the menu or toolbar. It is
     // only provided for advanced users who can use it by shorcut or add it to
     // the toolbar if they wish.
     a = actionCollection()->addAction( QLatin1String( "previous_deal" ));
     a->setText(i18nc("Start the game with the number one less than the current one", "Previous Deal"));
-    a->setIcon( KIcon( QLatin1String( "go-previous" )) );
-    a->setShortcut( KShortcut( Qt::ControlModifier | Qt::Key_Minus ) );
-    connect( a, SIGNAL(triggered(bool)), this, SLOT(previousDeal()) );
+    a->setIcon( QIcon::fromTheme( QLatin1String( "go-previous" )) );
+    actionCollection()->setDefaultShortcut(a, Qt::CTRL + Qt::Key_Minus);
+    connect(a, &QAction::triggered, this, &MainWindow::previousDeal);
 
     KStandardGameAction::load( this, SLOT(loadGame()), actionCollection() );
 
-    m_recentFilesAction = KStandardGameAction::loadRecent( this, SLOT(loadGame(KUrl)), actionCollection() );
-    m_recentFilesAction->loadEntries(KGlobal::config()->group( QString() ));
+    m_recentFilesAction = KStandardGameAction::loadRecent( this, SLOT(loadGame(QUrl)), actionCollection() );
+    m_recentFilesAction->loadEntries(KSharedConfig::openConfig()->group( QString() ));
 
     m_saveAction = KStandardGameAction::saveAs(this, SLOT(saveGame()), actionCollection());
-    m_saveAction->setShortcut( KShortcut( Qt::ControlModifier | Qt::Key_S ) );
+    actionCollection()->setDefaultShortcut(m_saveAction, Qt::CTRL + Qt::Key_S);
 
     a = actionCollection()->addAction( QLatin1String( "game_stats" ));
     a->setText(i18n("Statistics"));
-    a->setIcon( KIcon( QLatin1String( "games-highscores" )) );
-    connect( a, SIGNAL(triggered(bool)), SLOT(showStats()) );
+    a->setIcon( QIcon::fromTheme( QLatin1String( "games-highscores" )) );
+    connect(a, &QAction::triggered, this, &MainWindow::showStats);
 
     KStandardGameAction::quit(this, SLOT(close()), actionCollection());
 
@@ -217,69 +218,69 @@ void MainWindow::setupActions()
     a = KStandardGameAction::hint( 0, 0, 0 );
     m_hintAction->setText( a->text() );
     m_hintAction->setIcon( a->icon() );
-    m_hintAction->setShortcut( a->shortcut() );
+    actionCollection()->setDefaultShortcut( m_hintAction, a->shortcut() );
     m_hintAction->setToolTip( a->toolTip() );
     m_hintAction->setWhatsThis( a->whatsThis() );
     delete a;
     QString actionName( KStandardGameAction::name( KStandardGameAction::Hint ) );
     actionCollection()->addAction( actionName, m_hintAction );
-    connect( m_hintAction, SIGNAL(triggered()), this, SLOT(toggleHints()) );
+    connect(m_hintAction, &QAction::triggered, this, &MainWindow::toggleHints);
 
     m_drawAction = actionCollection()->addAction( QLatin1String( "move_draw" ));
     m_drawAction->setText( i18nc("Take one or more cards from the deck, flip them, and place them in play", "Dra&w") );
-    m_drawAction->setIcon( KIcon( QLatin1String( "kpat" )) );
-    m_drawAction->setShortcut( Qt::Key_Tab );
+    m_drawAction->setIcon( QIcon::fromTheme( QLatin1String( "kpat" )) );
+    actionCollection()->setDefaultShortcut(m_drawAction, Qt::Key_Tab );
 
     m_dealAction = actionCollection()->addAction( QLatin1String( "move_deal" ));
     m_dealAction->setText( i18nc("Deal a new row of cards from the deck", "Dea&l Row") );
-    m_dealAction->setIcon( KIcon( QLatin1String( "kpat" )) );
-    m_dealAction->setShortcut( Qt::Key_Return );
+    m_dealAction->setIcon( QIcon::fromTheme( QLatin1String( "kpat" )) );
+    actionCollection()->setDefaultShortcut(m_dealAction, Qt::Key_Return );
 
     m_redealAction = actionCollection()->addAction( QLatin1String( "move_redeal" ));
     m_redealAction->setText( i18nc("Collect the cards in play, shuffle them and redeal them", "&Redeal") );
-    m_redealAction->setIcon( KIcon( QLatin1String( "roll" )) );
-    m_redealAction->setShortcut( Qt::Key_R );
+    m_redealAction->setIcon( QIcon::fromTheme( QLatin1String( "roll" )) );
+    actionCollection()->setDefaultShortcut(m_redealAction, Qt::Key_R );
 
     m_dropAction = new KToggleAction( actionCollection() );
     m_dropAction->setText( i18nc("Automatically move cards to the foundation piles", "Dro&p") );
-    m_dropAction->setIcon( KIcon( QLatin1String( "games-endturn" )) );
-    m_dropAction->setShortcut( Qt::Key_P );
+    m_dropAction->setIcon( QIcon::fromTheme( QLatin1String( "games-endturn" )) );
+    actionCollection()->setDefaultShortcut(m_dropAction, Qt::Key_P );
     actionCollection()->addAction( QLatin1String(  "move_drop" ), m_dropAction );
-    connect( m_dropAction, SIGNAL(triggered()), this, SLOT(toggleDrop()) );
+    connect(m_dropAction, &QAction::triggered, this, &MainWindow::toggleDrop);
 
 
     // Settings Menu
     a = actionCollection()->addAction( QLatin1String( "select_deck" ));
     a->setText(i18n("Change Appearance..."));
-    connect( a, SIGNAL(triggered(bool)), SLOT(configureAppearance()) );
-    a->setShortcuts( KShortcut( Qt::Key_F10 ) );
+    connect(a, &QAction::triggered, this, &MainWindow::configureAppearance);
+    actionCollection()->setDefaultShortcut(a, Qt::Key_F10 );
 
     m_autoDropEnabledAction = new KToggleAction(i18n("&Enable Autodrop"), this);
     actionCollection()->addAction( QLatin1String( "enable_autodrop" ), m_autoDropEnabledAction );
-    connect( m_autoDropEnabledAction, SIGNAL(triggered(bool)), SLOT(setAutoDropEnabled(bool)) );
+    connect(m_autoDropEnabledAction, &KToggleAction::triggered, this, &MainWindow::setAutoDropEnabled);
     m_autoDropEnabledAction->setChecked( Settings::autoDropEnabled() );
 
     m_solverEnabledAction = new KToggleAction(i18n("E&nable Solver"), this);
     actionCollection()->addAction( QLatin1String( "enable_solver" ), m_solverEnabledAction );
-    connect( m_solverEnabledAction, SIGNAL(triggered(bool)), SLOT(enableSolver(bool)) );
+    connect(m_solverEnabledAction, &KToggleAction::triggered, this, &MainWindow::enableSolver);
     m_solverEnabledAction->setChecked( Settings::solverEnabled() );
 
-    m_playSoundsAction = new KToggleAction( KIcon( QLatin1String( "preferences-desktop-sound") ), i18n("Play &Sounds" ), this );
+    m_playSoundsAction = new KToggleAction( QIcon::fromTheme( QLatin1String( "preferences-desktop-sound") ), i18n("Play &Sounds" ), this );
     actionCollection()->addAction( QLatin1String( "play_sounds" ), m_playSoundsAction );
-    connect( m_playSoundsAction, SIGNAL(triggered(bool)), SLOT(enableSounds(bool)) );
+    connect(m_playSoundsAction, &KToggleAction::triggered, this, &MainWindow::enableSounds);
     m_playSoundsAction->setChecked( Settings::playSounds() );
 
     m_rememberStateAction = new KToggleAction(i18n("&Remember State on Exit"), this);
     actionCollection()->addAction( QLatin1String( "remember_state" ), m_rememberStateAction );
-    connect( m_rememberStateAction, SIGNAL(triggered(bool)), SLOT(enableRememberState(bool)) );
+    connect(m_rememberStateAction, &KToggleAction::triggered, this, &MainWindow::enableRememberState);
     m_rememberStateAction->setChecked( Settings::rememberStateOnExit() );
 
 
     // Help Menu
     m_gameHelpAction = actionCollection()->addAction( QLatin1String( "help_game" ));
-    m_gameHelpAction->setIcon( KIcon( QLatin1String( "help-browser" )) );
-    connect( m_gameHelpAction, SIGNAL(triggered(bool)), SLOT(helpGame()));
-    m_gameHelpAction->setShortcuts( KShortcut( Qt::ControlModifier | Qt::ShiftModifier | Qt::Key_F1 ) );
+    m_gameHelpAction->setIcon( QIcon::fromTheme( QLatin1String( "help-browser" )) );
+    connect(m_gameHelpAction, &QAction::triggered, this, &MainWindow::helpGame);
+    actionCollection()->setDefaultShortcut(m_gameHelpAction, Qt::CTRL + Qt::SHIFT + Qt::Key_F1 );
 
 
     // Hidden actions
@@ -287,44 +288,44 @@ void MainWindow::setupActions()
     {
         a = actionCollection()->addAction( QLatin1String( "themePreview" ));
         a->setText(i18n("Generate a theme preview image"));
-        connect( a, SIGNAL(triggered(bool)), SLOT(generateThemePreview()) );
-        a->setShortcuts( KShortcut( Qt::Key_F7 ) );
+        connect(a, &QAction::triggered, this, &MainWindow::generateThemePreview);
+        actionCollection()->setDefaultShortcut(a, Qt::Key_F7 );
 
         a = actionCollection()->addAction( QLatin1String( "snapshot" ));
         a->setText(i18n("Take Game Preview Snapshots"));
-        connect( a, SIGNAL(triggered(bool)), SLOT(slotSnapshot()) );
-        a->setShortcuts( KShortcut( Qt::Key_F8 ) );
+        connect(a, &QAction::triggered, this, &MainWindow::slotSnapshot);
+        actionCollection()->setDefaultShortcut(a, Qt::Key_F8);
 
         a = actionCollection()->addAction( QLatin1String( "random_set" ));
         a->setText(i18n("Random Cards"));
-        connect( a, SIGNAL(triggered(bool)), SLOT(slotPickRandom()) );
-        a->setShortcuts( KShortcut( Qt::Key_F9 ) );
+        connect(a, &QAction::triggered, this, &MainWindow::slotPickRandom);
+        actionCollection()->setDefaultShortcut(a, Qt::Key_F9);
     }
 
     // Keyboard navigation actions
     m_leftAction = actionCollection()->addAction( QLatin1String( "focus_left" ));
     m_leftAction->setText("Move Focus to Previous Pile");
-    m_leftAction->setShortcuts( KShortcut( Qt::Key_Left ) );
+    actionCollection()->setDefaultShortcut(m_leftAction, Qt::Key_Left );
 
     m_rightAction = actionCollection()->addAction( QLatin1String( "focus_right" ));
     m_rightAction->setText("Move Focus to Next Pile");
-    m_rightAction->setShortcuts( KShortcut( Qt::Key_Right ) );
+    actionCollection()->setDefaultShortcut(m_rightAction, Qt::Key_Right );
 
     m_upAction = actionCollection()->addAction( QLatin1String( "focus_up" ));
     m_upAction->setText("Move Focus to Card Below");
-    m_upAction->setShortcuts( KShortcut( Qt::Key_Up ) );
+    actionCollection()->setDefaultShortcut(m_upAction, Qt::Key_Up );
 
     m_downAction = actionCollection()->addAction( QLatin1String( "focus_down" ));
     m_downAction->setText("Move Focus to Card Above");
-    m_downAction->setShortcuts( KShortcut( Qt::Key_Down ) );
+    actionCollection()->setDefaultShortcut(m_downAction, Qt::Key_Down );
 
     m_cancelAction = actionCollection()->addAction( QLatin1String( "focus_cancel" ));
     m_cancelAction->setText("Cancel Focus");
-    m_cancelAction->setShortcuts( KShortcut( Qt::Key_Escape ) );
+    actionCollection()->setDefaultShortcut(m_cancelAction, Qt::Key_Escape );
 
     m_pickUpSetDownAction = actionCollection()->addAction( QLatin1String( "focus_activate" ));
     m_pickUpSetDownAction->setText("Pick Up or Set Down Focus");
-    m_pickUpSetDownAction->setShortcuts( KShortcut( Qt::Key_Space ) );
+    actionCollection()->setDefaultShortcut(m_pickUpSetDownAction, Qt::Key_Space );
 
     // showMenubar isn't a part of KStandardGameAction
     m_showMenubarAction = KStandardAction::showMenubar(this, SLOT(toggleMenubar()), actionCollection());
@@ -348,7 +349,7 @@ void MainWindow::helpGame()
         QString anchor = QString::fromUtf8( di->untranslatedBaseName() );
         anchor = anchor.toLower();
         anchor = anchor.remove('\'').replace('&', "and").replace(' ', '-');
-        KToolInvocation::invokeHelp(anchor);
+        KHelpClient::invokeHelp(anchor);
     }
 }
 
@@ -446,8 +447,8 @@ void MainWindow::configureAppearance()
                          i18n("Select a theme for non-card game elements")
                        );
 
-        connect( provider, SIGNAL(currentThemeChanged(const KgTheme*)), SLOT(appearanceChanged()) );
-        connect( dialog, SIGNAL(settingsChanged(QString)), this, SLOT(appearanceChanged()) );
+        connect(provider, &KgThemeProvider::currentThemeChanged, this, &MainWindow::appearanceChanged);
+        connect(dialog, &KConfigDialog::settingsChanged, this, &MainWindow::appearanceChanged);
         dialog->show();
     }
 }
@@ -532,8 +533,8 @@ void MainWindow::setGameType(int id)
                                   " there is no current game.",
                                   "Help &with %1", di->baseName().replace('&', "&&")));
 
-    connect(m_dealer, SIGNAL(solverStateChanged(QString)), SLOT(updateSolverDescription(QString)));
-    connect(m_dealer, SIGNAL(updateMoves(int)), SLOT(slotUpdateMoves(int)));
+    connect(m_dealer, &DealerScene::solverStateChanged, this, &MainWindow::updateSolverDescription);
+    connect(m_dealer, &DealerScene::updateMoves, this, &MainWindow::slotUpdateMoves);
 
     m_solverStatusLabel->setText(QString());
     m_solverStatusLabel->setVisible(true);
@@ -559,7 +560,7 @@ void MainWindow::slotShowGameSelectionScreen()
         if (!m_selector)
         {
             m_selector = new GameSelectionScene(this);
-            connect( m_selector, SIGNAL(gameSelected(int)), SLOT(slotGameSelected(int)) );
+            connect(m_selector, &GameSelectionScene::gameSelected, this, &MainWindow::slotGameSelected);
         }
         m_view->setScene(m_selector);
 
@@ -599,41 +600,41 @@ void MainWindow::updateActions()
     // If a dealer exists, connect the game actions to it.
     if ( m_dealer )
     {
-        connect( m_dealer, SIGNAL(undoPossible(bool)), m_undoAction, SLOT(setEnabled(bool)) );
-        connect( m_dealer, SIGNAL(redoPossible(bool)), m_redoAction, SLOT(setEnabled(bool)) );
+        connect(m_dealer, &DealerScene::undoPossible, m_undoAction, &QAction::setEnabled);
+        connect(m_dealer, &DealerScene::redoPossible, m_redoAction, &QAction::setEnabled);
 
-        connect( m_dealer, SIGNAL(hintActive(bool)), m_hintAction, SLOT(setChecked(bool)) );
-        connect( m_dealer, SIGNAL(gameInProgress(bool)), m_hintAction, SLOT(setEnabled(bool)) );
+        connect(m_dealer, &DealerScene::hintActive, m_hintAction, &QAction::setChecked);
+        connect(m_dealer, &DealerScene::gameInProgress, m_hintAction, &QAction::setEnabled);
 
-        connect( m_dealer, SIGNAL(demoActive(bool)), this, SLOT(toggleDemoAction(bool)) );
-        connect( m_dealer, SIGNAL(gameInProgress(bool)), m_demoAction, SLOT(setEnabled(bool)) );
+        connect(m_dealer, &DealerScene::demoActive, this, &MainWindow::toggleDemoAction);
+        connect(m_dealer, &DealerScene::gameInProgress, m_demoAction, &QAction::setEnabled);
 
-        connect( m_dealer, SIGNAL(dropActive(bool)), m_dropAction, SLOT(setChecked(bool)) );
-        connect( m_dealer, SIGNAL(gameInProgress(bool)), m_dropAction, SLOT(setEnabled(bool)) );
+        connect(m_dealer, &DealerScene::dropActive, m_dropAction, &QAction::setChecked);
+        connect(m_dealer, &DealerScene::gameInProgress, m_dropAction, &QAction::setEnabled);
 
-        connect( m_dealer, SIGNAL(gameInProgress(bool)), m_saveAction, SLOT(setEnabled(bool)) );
+        connect(m_dealer, &DealerScene::gameInProgress, m_saveAction, &QAction::setEnabled);
 
-        connect( m_leftAction, SIGNAL(triggered(bool)), m_dealer, SLOT(keyboardFocusLeft()) );
-        connect( m_rightAction, SIGNAL(triggered(bool)), m_dealer, SLOT(keyboardFocusRight()) );
-        connect( m_upAction, SIGNAL(triggered(bool)), m_dealer, SLOT(keyboardFocusUp()) );
-        connect( m_downAction, SIGNAL(triggered(bool)), m_dealer, SLOT(keyboardFocusDown()) );
-        connect( m_cancelAction, SIGNAL(triggered(bool)), m_dealer, SLOT(keyboardFocusCancel()) );
-        connect( m_pickUpSetDownAction, SIGNAL(triggered(bool)), m_dealer, SLOT(keyboardFocusSelect()) );
+        connect(m_leftAction, &QAction::triggered, m_dealer, &DealerScene::keyboardFocusLeft);
+        connect(m_rightAction, &QAction::triggered, m_dealer, &DealerScene::keyboardFocusRight);
+        connect(m_upAction, &QAction::triggered, m_dealer, &DealerScene::keyboardFocusUp);
+        connect(m_downAction, &QAction::triggered, m_dealer, &DealerScene::keyboardFocusDown);
+        connect(m_cancelAction, &QAction::triggered, m_dealer, &DealerScene::keyboardFocusCancel);
+        connect(m_pickUpSetDownAction, &QAction::triggered, m_dealer, &DealerScene::keyboardFocusSelect);
 
         if ( m_dealer->actions() & DealerScene::Draw )
         {
-            connect( m_drawAction, SIGNAL(triggered(bool)), m_dealer, SLOT(drawDealRowOrRedeal()) );
-            connect( m_dealer, SIGNAL(newCardsPossible(bool)), m_drawAction, SLOT(setEnabled(bool)) );
+            connect(m_drawAction, &QAction::triggered, m_dealer, &DealerScene::drawDealRowOrRedeal);
+            connect(m_dealer, &DealerScene::newCardsPossible, m_drawAction, &QAction::setEnabled);
         }
         else if ( m_dealer->actions() & DealerScene::Deal )
         {
-            connect( m_dealAction, SIGNAL(triggered(bool)), m_dealer, SLOT(drawDealRowOrRedeal()) );
-            connect( m_dealer, SIGNAL(newCardsPossible(bool)), m_dealAction, SLOT(setEnabled(bool)) );
+            connect(m_dealAction, &QAction::triggered, m_dealer, &DealerScene::drawDealRowOrRedeal);
+            connect(m_dealer, &DealerScene::newCardsPossible, m_dealAction, &QAction::setEnabled);
         }
         else if ( m_dealer->actions() & DealerScene::Redeal )
         {
-            connect( m_redealAction, SIGNAL(triggered(bool)), m_dealer, SLOT(drawDealRowOrRedeal()) );
-            connect( m_dealer, SIGNAL(newCardsPossible(bool)), m_redealAction, SLOT(setEnabled(bool)) );
+            connect(m_redealAction, &QAction::triggered, m_dealer, &DealerScene::drawDealRowOrRedeal);
+            connect(m_dealer, &DealerScene::newCardsPossible, m_redealAction, &QAction::setEnabled);
         }
 
         guiFactory()->unplugActionList( this, "dealer_options" );
@@ -678,8 +679,8 @@ void MainWindow::updateSoundEngine()
             if ( !m_soundEngine )
                 m_soundEngine = new SoundEngine( this );
 
-            connect( m_dealer, SIGNAL(cardsPickedUp()), m_soundEngine, SLOT(cardsPickedUp()) );
-            connect( m_dealer, SIGNAL(cardsPutDown()), m_soundEngine, SLOT(cardsPutDown()) );
+            connect(m_dealer, &DealerScene::cardsPickedUp, m_soundEngine, &SoundEngine::cardsPickedUp);
+            connect(m_dealer, &DealerScene::cardsPutDown, m_soundEngine, &SoundEngine::cardsPutDown);
         }
         else if ( m_soundEngine )
         {
@@ -728,7 +729,7 @@ void MainWindow::toggleDemo()
 void MainWindow::toggleDemoAction(bool active) 
 {
     m_demoAction->setChecked( active );
-    m_demoAction->setIcon( KIcon( QLatin1String( active ? "media-playback-pause" : "media-playback-start" ) ) );
+    m_demoAction->setIcon( QIcon::fromTheme( QLatin1String( active ? "media-playback-pause" : "media-playback-start" ) ) );
 }
 
 void MainWindow::toggleMenubar()
@@ -755,7 +756,7 @@ void MainWindow::saveNewToolbarConfig()
 
 void MainWindow::closeEvent(QCloseEvent *e)
 {
-    QString stateFileName = KStandardDirs::locateLocal( "appdata", saved_state_file );
+    QString stateFileName = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + saved_state_file ;
     QFile stateFile( stateFileName );
 
     // Remove the existing state file, if any.
@@ -786,7 +787,7 @@ void MainWindow::newNumberedDeal()
     if ( !m_dealDialog )
     {
         m_dealDialog = new NumberedDealDialog( this );
-        connect( m_dealDialog, SIGNAL(dealChosen(int,int)), this, SLOT(startNumbered(int,int)) );
+        connect(m_dealDialog, &NumberedDealDialog::dealChosen, this, &MainWindow::startNumbered);
     }
 
     if ( m_dealer )
@@ -827,7 +828,7 @@ void MainWindow::previousDeal()
 }
 
 
-bool MainWindow::loadGame( const KUrl & url, bool addToRecentFiles )
+bool MainWindow::loadGame( const QUrl & url, bool addToRecentFiles )
 {
     QString fileName;
     if( !KIO::NetAccess::download( url, fileName, this ) )
@@ -927,14 +928,15 @@ bool MainWindow::loadGame( const KUrl & url, bool addToRecentFiles )
 
 void MainWindow::loadGame()
 {
-    KFileDialog dialog( dialogUrl, "", this, 0 );
-    dialog.setOperationMode( KFileDialog::Opening );
-    dialog.setMimeFilter( QStringList() << saveFileMimeType << legacySaveFileMimeType << "all/allfiles" );
-    dialog.setCaption( i18n("Load") );
+    QFileDialog dialog(this);
+    dialog.selectUrl(dialogUrl);
+    dialog.setAcceptMode( QFileDialog::AcceptOpen );
+    dialog.setMimeTypeFilters( QStringList() << saveFileMimeType << legacySaveFileMimeType << "all/allfiles" );
+    dialog.setWindowTitle( i18n("Load") );
 
-    if ( dialog.exec() == KFileDialog::Accepted )
+    if ( dialog.exec() == QFileDialog::Accepted )
     {
-        KUrl url = dialog.selectedUrl();
+        QUrl url = dialog.selectedUrls().at(0);
         if ( !url.isEmpty() )
             loadGame( url, true );
     }
@@ -945,20 +947,21 @@ void MainWindow::saveGame()
     if ( !m_dealer )
         return;
 
-    KFileDialog dialog( dialogUrl, "", this, 0 );
-    dialog.setOperationMode( KFileDialog::Saving );
-    dialog.setMimeFilter( QStringList() << saveFileMimeType << legacySaveFileMimeType, saveFileMimeType );
+    QFileDialog dialog( this );
+    dialog.selectUrl(dialogUrl);
+    dialog.setAcceptMode( QFileDialog::AcceptSave );
+    dialog.setMimeTypeFilters( QStringList() << saveFileMimeType << legacySaveFileMimeType );
     dialog.setConfirmOverwrite( true );
-    dialog.setCaption( i18n("Save") );
-    if ( dialog.exec() != KFileDialog::Accepted )
+    dialog.setWindowTitle( i18n("Save") );
+    if ( dialog.exec() != QFileDialog::Accepted )
         return;
 
-    KUrl url = dialog.selectedUrl();
+    QUrl url = dialog.selectedUrls().at(0);
     if ( url.isEmpty() )
         return;
 
     QFile localFile;
-    KTemporaryFile tempFile;
+    QTemporaryFile tempFile;
     if ( url.isLocalFile() )
     {
         localFile.setFileName( url.toLocalFile() );
@@ -977,8 +980,7 @@ void MainWindow::saveGame()
         }
     }
     QFile & file = url.isLocalFile() ? localFile : tempFile;
-
-    if ( dialog.currentFilterMimeType()->is( legacySaveFileMimeType ) )
+    if ( dialog.selectedNameFilter() == legacySaveFileMimeType )
     {
         m_dealer->saveLegacyFile( &file );
     }
@@ -986,7 +988,6 @@ void MainWindow::saveGame()
     {
         m_dealer->saveFile( &file );
     }
-
     file.close();
 
     if ( !url.isLocalFile() && !KIO::NetAccess::upload( file.fileName(), url, this ) )
@@ -1070,4 +1071,4 @@ void MainWindow::generateThemePreview()
     m_view->setMaximumSize( QWIDGETSIZE_MAX, QWIDGETSIZE_MAX );
 }
 
-#include "mainwindow.moc"
+
